;; Generated package description from project.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "project" "0.11.2.0.20260627.31" "Operations on the current project" '((emacs "26.1") (xref "1.7.0")) :commit "b24ed25b39f346370e1b90eebe86fcacdd4e48e3" :url "https://elpa.gnu.org/packages/project.html")
